Module filter
git_
stats
0.2.2
Module filter
Module Items
Functions
In git_
stats::
logic
git_stats
::
logic
Module
filter
Functions

compile_
authors
Compile author regex patterns, surfacing a clear error on a bad pattern.
keep_
indices
Indices of the commits to keep after author and date filtering.