Functions
- render_
reviews - Render the per-reviewer table. For consistency with the stats table, its header row is bold and underlined (gated by yansi’s global color condition).
- render_
stats - Render the per-author stats table. The last row is expected to be the “Total” row (shown bold); the header row is bold and underlined. Styling is gated by yansi’s global condition, so it is plain text when color is disabled.